@@ -9,7 +9,7 @@
 
 #include "jdlib/misctime.h"
 
-#include "controlid.h"
+#include "control/controlid.h"
 
 #include <sys/time.h>
 
@@ -22,7 +22,7 @@ ArticleViewInfo::ArticleViewInfo( const std::string& url )
     struct timeval tv;
     struct timezone tz;
     gettimeofday( &tv, &tz );
-    set_url( url_article() + MISC::timevaltostr( tv ) + ARTICLE_SIGN + "_PREV_" );
+    set_url( url_article() + MISC::timevaltostr( tv ) + ARTICLE_SIGN + "_PREV_", false );
 
 #ifdef _DEBUG
     std::cout << "ArticleViewInfo::ArticleViewInfo " << get_url() << std::endl;
@@ -46,14 +46,3 @@ DrawAreaBase* ArticleViewInfo::create_drawarea()
 {
     return Gtk::manage( new ARTICLE::DrawAreaInfo( url_article() ) );
 }
-
-//
-// ウィジットのパッキング
-//
-// ArticleViewBase::pack_widget()をオーパロードしてツールバーをパックしない
-//
-void ArticleViewInfo::pack_widget()
-{
-    pack_start( *drawarea() );
-}
-
