@@ -64,8 +64,6 @@ LayoutTree::LayoutTree( const std::string& url, bool show_abone )
     m_article = DBTREE::get_article( m_url );
     assert( m_article );
 
-    m_dummy_str = '\0';
-
     clear();
 }
 
@@ -204,19 +202,26 @@ LAYOUT* LayoutTree::create_layout_br()
     LAYOUT* tmplayout = create_layout( DBTREE::NODE_BR );
     m_last_layout->next_layout = tmplayout;
     m_last_layout = tmplayout;
-
-    // DrawAreaBase::set_caret() において layout->text != NULL の場合
-    // キャレット移動の計算がうまくいかないのでダミーのテキストバッファをセットする
-    tmplayout->text = &m_dummy_str;
-
     return tmplayout;
 }
 
 
 //
-// スペースノード作成
+// 水平線ノード作成
 //
-LAYOUT* LayoutTree::create_layout_sp( const int type )
+LAYOUT* LayoutTree::create_layout_hr()
+{
+    LAYOUT* tmplayout = create_layout( DBTREE::NODE_HR );
+    m_last_layout->next_layout = tmplayout;
+    m_last_layout = tmplayout;
+    return tmplayout;
+}
+
+
+//
+// 水平スペースノード作成
+//
+LAYOUT* LayoutTree::create_layout_hspace( const int type )
 {
     LAYOUT* tmplayout = create_layout( type );
     m_last_layout->next_layout = tmplayout;
@@ -248,12 +253,24 @@ LAYOUT* LayoutTree::create_layout_div( const int id )
 //
 LAYOUT* LayoutTree::create_layout_img( const char* link )
 {
-    LAYOUT* img = create_layout( DBTREE::NODE_IMG );
-    m_last_layout->next_layout = img;
-    m_last_layout = img;
-    img->link = link;
+    LAYOUT* tmplayout = create_layout( DBTREE::NODE_IMG );
+    m_last_layout->next_layout = tmplayout;
+    m_last_layout = tmplayout;
+    tmplayout->link = link;
 
-    return img;
+    return tmplayout;
+}
+
+
+//
+// sssp ノード作成
+//
+LAYOUT* LayoutTree::create_layout_sssp( const char* link )
+{
+    LAYOUT* tmplayout = create_layout_img( link );
+    tmplayout->type = DBTREE::NODE_SSSP;
+
+    return tmplayout;
 }
 
 
@@ -378,6 +395,19 @@ void LayoutTree::append_block( DBTREE::NODE* block, const int res_number, IMGDAT
 
                 break;
 
+            case DBTREE::NODE_SSSP:
+
+                if( CONFIG::get_show_ssspicon() ){
+                    tmplayout = create_layout_sssp( tmpnode->linkinfo->link );
+                    tmplayout->link = tmpnode->linkinfo->link;
+                }
+                else{
+                    // 次が改行ノードの時は飛ばす
+                    if( tmpnode->next_node && tmpnode->next_node->type == DBTREE::NODE_BR )
+                        tmpnode = tmpnode->next_node;
+                }
+
+                break;
 
             case DBTREE::NODE_IDNUM:
                 tmplayout = create_layout_idnum( tmpnode->text, &tmpnode->color_text, tmpnode->bold );
@@ -386,13 +416,17 @@ void LayoutTree::append_block( DBTREE::NODE* block, const int res_number, IMGDAT
             case DBTREE::NODE_BR:
                 tmplayout = create_layout_br();
                 break;
+
+            case DBTREE::NODE_HR:
+                tmplayout = create_layout_hr();
+                break;
             
             case DBTREE::NODE_ZWSP: // 幅0スペース
-                tmplayout = create_layout_sp( tmpnode->type );
+                tmplayout = create_layout_hspace( tmpnode->type );
                 break;
 
             case DBTREE::NODE_HTAB: // 水平タブ
-                tmplayout = create_layout_sp( tmpnode->type );
+                tmplayout = create_layout_hspace( tmpnode->type );
                 break;
         }
 
