@@ -6,8 +6,9 @@
 #include "selectlistview.h"
 #include "toolbar.h"
 
+#include "control/controlid.h"
+
 #include "type.h"
-#include "controlid.h"
 
 using namespace BBSLIST;
 
@@ -30,11 +31,15 @@ void SelectListView::close_view()
 }
 
 
-void  SelectListView::operate_view( const int& control )
+const bool SelectListView::operate_view( const int control )
 {
     // ESCでダイアログを閉じる
-    if( control == CONTROL::Cancel ) close_view();
-    else BBSListViewBase::operate_view( control );
+    if( control == CONTROL::Cancel ){
+        close_view();
+        return true;
+    }
+
+    return BBSListViewBase::operate_view( control );
 }
 
 
