@@ -5,11 +5,11 @@
 
 #include "boardadmin.h"
 #include "boardview.h"
-#include "toolbar.h"
 
 #include "skeleton/msgdiag.h"
 
 #include "jdlib/miscutil.h"
+#include "jdlib/miscgtk.h"
 #include "jdlib/jdregex.h"
 
 #include "dbtree/interface.h"
@@ -17,17 +17,22 @@
 
 #include "config/globalconf.h"
 
+#include "sound/soundmanager.h"
+
+#include "control/controlid.h"
+#include "control/controlutil.h"
+
 #include "command.h"
 #include "session.h"
 #include "dndmanager.h"
 #include "sharedbuffer.h"
 #include "global.h"
-#include "controlid.h"
+#include "type.h"
 #include "prefdiagfactory.h"
 #include "httpcode.h"
-#include "controlutil.h"
 #include "colorid.h"
 #include "fontid.h"
+#include "compmanager.h"
 
 #include "icons/iconmanager.h"
 
@@ -50,13 +55,17 @@ using namespace BOARD;
 #define UNSORTED_COLUMN() do{ m_liststore->gobj()->sort_column_id = -2; } while(0)
 
 
-#define DEFAULT_COLMUN_WIDTH 50
+enum{
+    DEFAULT_COLMUN_WIDTH = 50
+};
+
 
 enum{
     COL_MARKVAL_OLD = -2,        // dat 落ち
     COL_MARKVAL_FINISHED = -1,   // キャッシュあり、新着無し、規定スレ数を越えている
     COL_MARKVAL_NORMAL = 0,      // 通常状態
-    COL_MARKVAL_NEWTHREAD,       // 新スレ
+    COL_MARKVAL_NEWTHREAD_HOUR,  // 新スレ( CONFIG::get_newthread_hour 時間以内 )
+    COL_MARKVAL_NEWTHREAD,       // 前回の板一覧読み込み時から新しく出来たスレ
     COL_MARKVAL_CACHED,          // キャッシュあり、新着無し
     COL_MARKVAL_UPDATED,         // キャッシュあり、新着有り
     COL_MARKVAL_BKMARKED,        // ブックマークされている、新着無し
@@ -70,7 +79,7 @@ enum
     SORTMODE_DESCEND,
 
     SORTMODE_MARK1, // 通常
-    SORTMODE_MARK2, // 新着を一番上に
+    SORTMODE_MARK2, // 新着をキャッシュの上に。後は通常
     SORTMODE_MARK3  // 反転
 };
 
@@ -101,7 +110,7 @@ m_treeview.append_column( *col ); \
 
 BoardView::BoardView( const std::string& url,const std::string& arg1, const std::string& arg2 )
     : SKELETON::View( url ),
-      m_treeview( CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
+      m_treeview( true, CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
       m_col_mark( NULL ),
       m_col_id( NULL ),
       m_col_subject( NULL ),
@@ -121,23 +130,6 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
-    set_toolbar( Gtk::manage( new BoardToolBar() ) );
-
-    get_boardtoolbar()->get_close_button().signal_clicked().connect( sigc::mem_fun( *this, &BoardView::close_view ) );
-    get_boardtoolbar()->m_entry_search.signal_changed().connect( sigc::mem_fun( *this, &BoardView::slot_changed_search ) );
-    get_boardtoolbar()->m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BoardView::slot_active_search ) );
-    get_boardtoolbar()->m_button_reload.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::reload ) );
-    get_boardtoolbar()->m_button_stop.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::stop ) );
-    get_boardtoolbar()->m_button_new_article.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_new_article ) );
-    get_boardtoolbar()->m_button_delete.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_delete ) );
-    get_boardtoolbar()->m_button_favorite.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_favorite ) );
-    get_boardtoolbar()->m_button_up_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_up_search ) );
-    get_boardtoolbar()->m_button_down_search.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::slot_push_down_search ) );
-    get_boardtoolbar()->m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &BoardView::slot_entry_operate ) );
-
-    if( SESSION::get_show_board_toolbar() ) get_boardtoolbar()->show_toolbar();
-
-    pack_start( *get_boardtoolbar(), Gtk::PACK_SHRINK );    
     pack_start( m_scrwin );
     show_all_children();    
 
@@ -183,7 +175,6 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     m_treeview.sig_scroll_event().connect( sigc::mem_fun(*this, &BoardView::slot_scroll_event ) );
 
     // D&D設定
-    m_treeview.set_reorderable_view( true );
     m_treeview.sig_drag_begin().connect( sigc::mem_fun(*this, &BoardView::slot_drag_begin ) );
     m_treeview.sig_drag_end().connect( sigc::mem_fun(*this, &BoardView::slot_drag_end ) );
 
@@ -191,11 +182,11 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     // ポップアップメニューの設定
     // アクショングループを作ってUIマネージャに登録
     action_group() = Gtk::ActionGroup::create();
-    action_group()->add( Gtk::Action::create( "BookMark", "ブックマーク設定/解除(_B)" ),
+    action_group()->add( Gtk::Action::create( "BookMark", "しおりを設定/解除(_B)" ),
                          sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_AUTO ) );
-    action_group()->add( Gtk::Action::create( "SetBookMark", "ブックマーク設定(_S)" ),  // 未使用
+    action_group()->add( Gtk::Action::create( "SetBookMark", "しおりを設定(_S)" ),  // 未使用
                          sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_SET ) );
-    action_group()->add( Gtk::Action::create( "UnsetBookMark", "ブックマーク解除(_U)" ),    // 未使用
+    action_group()->add( Gtk::Action::create( "UnsetBookMark", "しおりを解除(_U)" ),    // 未使用
                          sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_bookmark ), BOOKMARK_UNSET ) );
     action_group()->add( Gtk::Action::create( "OpenTab", "タブで開く(_T)" ), sigc::mem_fun( *this, &BoardView::slot_open_tab ) );
     action_group()->add( Gtk::Action::create( "Favorite_Article", "スレをお気に入りに追加(_F)..." ), sigc::mem_fun( *this, &BoardView::slot_favorite_thread ) );
@@ -203,7 +194,7 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     action_group()->add( Gtk::Action::create( "GotoTop", "一番上に移動(_T)" ), sigc::mem_fun( *this, &BoardView::goto_top ) );
     action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動(_M)" ), sigc::mem_fun( *this, &BoardView::goto_bottom ) );
     action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
-    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardView::delete_view ) );
+    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardView::slot_delete_logs ) );
     action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardView::open_selected_rows ) );
     action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_C)" ), sigc::mem_fun( *this, &BoardView::slot_copy_url ) );
     action_group()->add( Gtk::Action::create( "CopyTitleURL", "タイトルとURLをコピー(_U)" ), sigc::mem_fun( *this, &BoardView::slot_copy_title_url ) );
@@ -306,6 +297,12 @@ BoardView::~BoardView()
 }
 
 
+SKELETON::Admin* BoardView::get_admin()
+{
+    return BOARD::get_admin();
+}
+
+
 // アイコンのID取得
 const int BoardView::get_icon( const std::string& iconname )
 {
@@ -574,10 +571,10 @@ void BoardView::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::i
     Gtk::TreePath path = m_liststore->get_path( row );
 
 #ifdef _DEBUG
-    std::cout << "BoardView::slot_cell_data path = " << path.to_string() << std::endl;
+//    std::cout << "BoardView::slot_cell_data path = " << path.to_string() << std::endl;
 #endif
 
-    // ハイライト色
+    // ハイライト色 ( 抽出状態 )
     if( row[ m_columns.m_col_drawbg ] ){
         cell->property_cell_background() = CONFIG::get_color( COLOR_BACK_HIGHLIGHT_TREE );
         cell->property_cell_background_set() = true;
@@ -686,7 +683,7 @@ int BoardView::compare_col( int col, int sortmode, Gtk::TreeModel::Row& row_a, G
             num_a = row_a[ m_columns.m_col_mark_val ];
             num_b = row_b[ m_columns.m_col_mark_val ];
 
-            if( sortmode == SORTMODE_MARK2 ){ // 新着を一番上に
+            if( sortmode == SORTMODE_MARK2 ){ // 新着をキャッシュの上に
 
                 if( num_a == COL_MARKVAL_NEWTHREAD
                     && ( num_b != COL_MARKVAL_NEWTHREAD && num_b != COL_MARKVAL_BKMARKED_UPDATED && num_b != COL_MARKVAL_BKMARKED ) ){
@@ -865,18 +862,14 @@ void BoardView::show_view()
         return;
     }
 
-    // タイトル表示
-    set_title( DBTREE::board_name( get_url() ) );
-    BOARD::get_admin()->set_command( "set_title", get_url(), get_title() );
-
-    // タブに名前をセット
-    BOARD::get_admin()->set_command( "set_tablabel", get_url(), DBTREE::board_name( get_url() ) );
+    update_boardname();
 
 #if GTKMMVER >= 280
     m_treeview.unset_model();
 #endif
     m_liststore->clear();
     m_pre_query = std::string();
+    m_last_access_time = DBTREE::board_last_access_time( get_url() );
     m_loading = true;
     
     // download 開始
@@ -914,6 +907,18 @@ void BoardView::redraw_view()
 }
 
 
+//
+// スクロールバー再描画
+//
+void BoardView::redraw_scrollbar()
+{
+#ifdef _DEBUG
+    std::cout << "BoardView::redraw_scrollbar\n";
+#endif
+
+    m_scrwin.queue_draw();
+}
+
 
 //
 // 色、フォントの更新
@@ -933,13 +938,22 @@ void BoardView::relayout()
 //
 void BoardView::update_view()
 {
-#ifdef _DEBUG
-    std::cout << "BoardView::update_view " << get_url() << std::endl;
-#endif    
-
+    const int code = DBTREE::board_code( get_url() );
     m_updated = false;
     m_loading = false;
 
+#ifdef _DEBUG
+    std::cout << "BoardView::update_view " << get_url()
+              << " code = " << code << std::endl;
+#endif    
+
+    // 音を鳴らす
+    if( SESSION::is_online() && code != HTTP_INIT ){
+        if( code == HTTP_OK ) SOUND::play( SOUND::SOUND_RES );
+        else if( code == HTTP_NOT_MODIFIED ) SOUND::play( SOUND::SOUND_NO );
+        else SOUND::play( SOUND::SOUND_ERR );
+    }
+
     // 画面消去
 #if GTKMMVER >= 280
     m_treeview.unset_model();
@@ -1029,7 +1043,7 @@ void BoardView::close_view()
 //
 // 選択した行のログをまとめて削除
 //
-void BoardView::delete_view()
+void BoardView::slot_delete_logs()
 {
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
     std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
@@ -1049,12 +1063,12 @@ void BoardView::delete_view()
 //
 // viewの操作
 //
-void BoardView::operate_view( const int& control )
+const bool BoardView::operate_view( const int control )
 {
     bool open_tab = false;
 
     Gtk::TreePath path = m_treeview.get_current_path();;
-    if( path.empty() ) return;
+    if( path.empty() ) return false;
 
     switch( control ){
 
@@ -1104,11 +1118,11 @@ void BoardView::operate_view( const int& control )
             CORE::core_set_command( "switch_rightview" );
             break;
 
-        case CONTROL::ScrollLeft:
+        case CONTROL::ScrollLeftBoard:
             scroll_left();
             break;
 
-        case CONTROL::ScrollRight:
+        case CONTROL::ScrollRightBoard:
             scroll_right();
             break;
 
@@ -1124,6 +1138,15 @@ void BoardView::operate_view( const int& control )
             BOARD::get_admin()->set_command( "tab_right" );
             break;
 
+            // 戻る、進む
+        case CONTROL::PrevView:
+            back_viewhistory( 1 );
+            break;
+
+        case CONTROL::NextView:
+            forward_viewhistory( 1 );
+            break;
+
         case CONTROL::Quit:
             close_view();
             break;
@@ -1137,15 +1160,25 @@ void BoardView::operate_view( const int& control )
             break;
 
         case CONTROL::NewArticle:
-            slot_new_article();
+            write();
             break;
 
         case CONTROL::Delete:
         {
-            SKELETON::MsgDiag mdiag( NULL, "選択した行のログを削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            mdiag.set_default_response( Gtk::RESPONSE_YES );
-            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
-            delete_view();
+
+            if( CONFIG::get_show_deldiag() ){
+
+                SKELETON::MsgCheckDiag mdiag( NULL,
+                                              "選択した行のログを削除しますか？",
+                                              "今後表示しない(常に削除)(_D)",
+                                              Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+                mdiag.set_title( "削除確認" );
+                const int ret = mdiag.run();
+                if( ret != Gtk::RESPONSE_YES ) return true;
+                if( mdiag.get_chkbutton().get_active() ) CONFIG::set_show_deldiag( false );
+            }
+
+            slot_delete_logs();
             break;
         }
 
@@ -1156,25 +1189,21 @@ void BoardView::operate_view( const int& control )
 
         // 検索
         case CONTROL::Search:
-            if( get_boardtoolbar() ){
-                m_search_invert = false;
-                get_boardtoolbar()->m_entry_search.grab_focus();
-            }
+            m_search_invert = false;
+            BOARD::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchInvert:
-            if( get_boardtoolbar() ){
-                m_search_invert = true;
-                get_boardtoolbar()->m_entry_search.grab_focus();
-            }
+            m_search_invert = true;
+            BOARD::get_admin()->set_command( "focus_toolbar_search" );
             break;
 
         case CONTROL::SearchNext:
-            slot_push_down_search();
+            down_search();
             break;
     
         case CONTROL::SearchPrev:
-            slot_push_up_search();
+            up_search();
             break;
 
             // サイドバー表示/非表示
@@ -1186,7 +1215,12 @@ void BoardView::operate_view( const int& control )
         case CONTROL::ShowMenuBar:
             CORE::core_set_command( "toggle_menubar" );
             break;
+
+        default:
+            return false;
     }
+
+    return true;
 }
 
 
@@ -1261,19 +1295,6 @@ void BoardView::scroll_right()
 }
 
 
-
-//
-// ツールバー表示切り替え
-//
-void BoardView::toggle_toolbar()
-{
-    if( ! get_boardtoolbar() ) return;
-
-    if( SESSION::get_show_board_toolbar() ) get_boardtoolbar()->show_toolbar();
-    else get_boardtoolbar()->hide_toolbar();
-}
-
-
 //
 // 上へ移動
 //
@@ -1310,12 +1331,6 @@ void BoardView::page_down()
 } 
    
 
-BoardToolBar* BoardView::get_boardtoolbar()
-{
-    return dynamic_cast< BoardToolBar* >( get_toolbar() );
-}
-
-
 //
 // ポップアップメニュー取得
 //
@@ -1465,10 +1480,15 @@ void BoardView::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel::Row
         art->show_updateicon( false );
     }
     // キャッシュ無し、新着
-    else if( art->get_hour() < CONFIG::get_newthread_hour() ){
+    else if( art->get_since_time() > m_last_access_time ){
         mark_val = COL_MARKVAL_NEWTHREAD;
         row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::NEWTHREAD );
     }
+    // キャッシュ無し、新着( CONFIG::get_newthread_hour() 時間以内 )
+    else if( art->get_hour() < CONFIG::get_newthread_hour() ){
+        mark_val = COL_MARKVAL_NEWTHREAD_HOUR;
+        row[ m_columns.m_col_mark ] = ICON::get_icon( ICON::NEWTHREAD_HOUR );
+    }
     //キャッシュ無し
     else{
         mark_val = COL_MARKVAL_NORMAL;
@@ -1519,7 +1539,7 @@ bool BoardView::slot_button_press( GdkEventButton* event )
 bool BoardView::slot_button_release( GdkEventButton* event )
 {
     /// マウスジェスチャ
-    int mg = get_control().MG_end( event );
+    const int mg = get_control().MG_end( event );
 
     // ホイールマウスジェスチャ
     // 実行された場合は何もしない 
@@ -1530,8 +1550,8 @@ bool BoardView::slot_button_release( GdkEventButton* event )
         return true;
     }
 
-    int x = (int)event->x;
-    int y = (int)event->y;
+    const int x = (int)event->x;
+    const int y = (int)event->y;
     Gtk::TreeModel::Path path;
     Gtk::TreeViewColumn* column;
     int cell_x;
@@ -1593,8 +1613,8 @@ bool BoardView::slot_motion_notify( GdkEventMotion* event )
     /// マウスジェスチャ
     get_control().MG_motion( event );
 
-    int x = (int)event->x;
-    int y = (int)event->y;
+    const int x = (int)event->x;
+    const int y = (int)event->y;
     Gtk::TreeModel::Path path;
     Gtk::TreeView::Column* column;
     int cell_x;
@@ -1631,11 +1651,11 @@ bool BoardView::slot_key_press( GdkEventKey* event )
         if( m_pressed_key == CONTROL::OpenArticle ) return true;
         if( m_pressed_key == CONTROL::OpenArticleTab ) return true;
 
-        operate_view( m_pressed_key );
+        if( operate_view( m_pressed_key ) ) return true;
     }
-    else release_keyjump_key( event->keyval );
+    else if( release_keyjump_key( event->keyval ) ) return true;
 
-    return true;
+    return false;
 }
 
 
@@ -1770,7 +1790,7 @@ void BoardView::slot_favorite_board()
 //
 // 新スレをたてる
 //
-void BoardView::slot_new_article()
+void BoardView::write()
 {
     CORE::core_set_command( "create_new_thread", get_url() );
 }
@@ -1779,7 +1799,7 @@ void BoardView::slot_new_article()
 //
 // ツールバーの削除ボタン
 //
-void BoardView::slot_push_delete()
+void BoardView::delete_view()
 {
     show_popupmenu( "popup_menu_delete", false );
 }
@@ -1788,7 +1808,7 @@ void BoardView::slot_push_delete()
 //
 // ツールバーのお気に入りボタン
 //
-void BoardView::slot_push_favorite()
+void BoardView::set_favorite()
 {
     show_popupmenu( "popup_menu_favorite", false );
 }
@@ -1802,7 +1822,7 @@ void BoardView::slot_copy_url()
     if( m_path_selected.empty() ) return;
 
     std::string url = DBTREE::url_readcgi( path2daturl( m_path_selected ), 0, 0 );
-    COPYCLIP( url );
+    MISC::CopyClipboard( url );
 }
 
 
@@ -1818,7 +1838,7 @@ void BoardView::slot_copy_title_url()
     ss << name << std::endl
        << url << std::endl;
 
-    COPYCLIP( ss.str() );
+    MISC::CopyClipboard( ss.str() );
 }
 
 
@@ -1910,12 +1930,10 @@ std::string BoardView::path2daturl( const Gtk::TreePath& path )
 //
 bool BoardView::drawout()
 {
-    if( ! get_boardtoolbar() ) return false;
-
     int hit = 0;
     bool reset = false;
 
-    std::string query = get_boardtoolbar()->m_entry_search.get_text();
+    std::string query = get_search_query();
 
     // 空の時はリセット
     if( query.empty() ) reset = true;
@@ -1965,8 +1983,14 @@ bool BoardView::drawout()
 //
 // 検索ボックスの文字列が変わった
 //
-void BoardView::slot_changed_search()
+void BoardView::set_search_query( const std::string& query )
 {
+    SKELETON::View::set_search_query( query );
+
+#ifdef _DEBUG
+    std::cout << "BoardView::set_search_query query = " << get_search_query() << std::endl;
+#endif
+
     if( CONFIG::get_inc_search_board() ){
         drawout();
         m_pre_query = std::string();
@@ -1975,18 +1999,16 @@ void BoardView::slot_changed_search()
 
 
 //
-// 検索移動
+// 検索実行
 //
-void BoardView::slot_active_search()
+void BoardView::exec_search()
 {
-    if( ! get_boardtoolbar() ) return;
-    if( get_boardtoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_boardtoolbar()->m_entry_search.get_text();
+    std::string query = get_search_query();
     if( m_pre_query != query ){
         drawout();
         focus_view();
         m_pre_query = query;
+        CORE::get_completion_manager()->set_query( CORE::COMP_SEARCH_BOARD, query );
         return;
     }
 
@@ -2038,40 +2060,31 @@ void BoardView::slot_active_search()
 
 
 // 前検索
-void BoardView::slot_push_up_search()
+void BoardView::up_search()
 {
     m_search_invert = true;
-    slot_active_search();
+    exec_search();
 }
 
 
 
 // 後検索
-void BoardView::slot_push_down_search()
+void BoardView::down_search()
 {
     m_search_invert = false;
-    slot_active_search();
-}
-
-
-// キャッシュ内のログ検索
-void BoardView::search_cache()
-{
-    if( ! get_boardtoolbar() ) return;
-    if( get_boardtoolbar()->m_entry_search.completion() ) return;
-
-    std::string query = get_boardtoolbar()->m_entry_search.get_text();
-    CORE::core_set_command( "open_article_searchlog", get_url() , query );
+    exec_search();
 }
 
 
 //
 // 検索entryの操作
 //
-void BoardView::slot_entry_operate( int controlid )
+void BoardView::operate_search( const std::string& controlid )
 {
-    if( controlid == CONTROL::Cancel ) focus_view();
-    else if( controlid == CONTROL::SearchCache ) search_cache();
+    int id = atoi( controlid.c_str() );
+
+    if( id == CONTROL::Cancel ) focus_view();
+    else if( id == CONTROL::SearchCache ) CORE::core_set_command( "open_article_searchlog", get_url() , get_search_query() );
 }
 
 
@@ -2100,6 +2113,39 @@ void BoardView::slot_preferences_article()
 }
 
 
+//
+// 板名更新
+//
+void BoardView::update_boardname()
+{
+    // タイトル表示
+    set_title( DBTREE::board_name( get_url() ) );
+    BOARD::get_admin()->set_command( "set_title", get_url(), get_title() );
+
+    // タブに名前をセット
+    BOARD::get_admin()->set_command( "set_tablabel", get_url(), DBTREE::board_name( get_url() ) );
+}
+
+
+//
+// 戻る
+//
+void BoardView::back_viewhistory( const int count )
+{
+    BOARD::get_admin()->set_command( "back_viewhistory", get_url(), MISC::itostr( count ) );
+}
+
+
+//
+// 進む
+//
+void BoardView::forward_viewhistory( const int count )
+{
+    BOARD::get_admin()->set_command( "forward_viewhistory", get_url(), MISC::itostr( count ) );
+}
+
+
+
 //
 // datを保存
 //
