@@ -34,8 +34,10 @@ std::string get_default_font()
 {
     std::set< std::string > set_fonts = MISC::get_font_families();
 
+    // 上の方が優先順位が高い
     IS_DEFAULT_FONT( "IPA モナー Pゴシック" );
     IS_DEFAULT_FONT( "IPAMonaPGothic" );
+    IS_DEFAULT_FONT( "Mona-VLGothic" );
     IS_DEFAULT_FONT( "Mona" );
     IS_DEFAULT_FONT( "VL Pゴシック" );
     IS_DEFAULT_FONT( "VL PGothic" );
@@ -90,25 +92,8 @@ const bool ConfigItems::load()
     // 自前でウィンドウ配置を管理する
     manage_winpos = cf.get_option( "manage_winpos", CONF_MANAGE_WINPOS );
 
-    std::string defaultfont = get_default_font();
-
     // フォント
-    fontname[ FONT_MAIN ] = cf.get_option( "fontname_main", defaultfont + " " + std::string( CONF_FONTSIZE_THREAD ) );
-
-    // ポップアップのフォント
-    fontname[ FONT_POPUP ] = cf.get_option( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
-
-    // スレ一覧のフォント
-    fontname[ FONT_BBS ] = cf.get_option( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
-
-    // 板一覧のフォント
-    fontname[ FONT_BOARD ] = cf.get_option( "fontname_board", fontname[ FONT_BBS ] );
-
-    // 書き込みウィンドウのフォント
-    fontname[ FONT_MESSAGE ] = cf.get_option( "fontname_message", fontname[ FONT_MAIN ] );
-
-    // Gtk::Entryのデフォルトフォント
-    fontname[ FONT_ENTRY_DEFAULT ] = MISC::get_entry_font();
+    set_fonts( cf );
 
     // レスを参照するときに前に付ける文字
     ref_prefix = cf.get_option( "ref_prefix", CONF_REF_PREFIX );
@@ -185,9 +170,15 @@ const bool ConfigItems::load()
     // インライン画像を表示する
     use_inline_image = cf.get_option( "use_inline_image", CONF_INLINE_IMG );
 
+    // ssspアイコン表示
+    show_ssspicon = cf.get_option( "show_ssspicon", CONF_SHOW_SSSPICON );
+
     // 画像にモザイクをかける
     use_mosaic = cf.get_option( "use_mosaic", CONF_USE_MOSAIC );
 
+    // モザイクの大きさ
+    mosaic_size = cf.get_option( "mosaic_size", CONF_MOSAIC_SIZE );
+
     // 画像をデフォルトでウィンドウサイズに合わせる
     zoom_to_fit = cf.get_option( "zoom_to_fit", CONF_ZOOM_TO_FIT );
 
@@ -215,10 +206,17 @@ const bool ConfigItems::load()
     // bbsmenu.html内にあるリンクは全て板とみなす
     use_link_as_board = cf.get_option( "use_link_as_board", CONF_USE_LINK_AS_BOARD );
 
+    // 板移転時に確認ダイアログを表示する
+    show_movediag = cf.get_option( "show_movediag", CONF_SHOW_MOVEDIAG );
+
     // スレタイ検索用メニュータイトルアドレス
     menu_search_title = cf.get_option( "menu_search_title", CONF_MENU_SEARCH_TITLE );
     url_search_title = cf.get_option( "url_search_title", CONF_URL_SEARCH_TITLE );
 
+    // p2 書き込み用アドレス
+    url_writep2 = cf.get_option( "url_writep2", CONF_URL_WRITEP2 );
+    url_resp2 = cf.get_option( "url_resp2", CONF_URL_RESP2 );
+
     // スレタイ検索用正規表現
     regex_search_title = cf.get_option( "regex_search_title", CONF_REGEX_SEARCH_TITLE );
 
@@ -244,6 +242,9 @@ const bool ConfigItems::load()
     // スレ一覧でインクリメント検索をする
     inc_search_board = cf.get_option( "inc_search_board", CONF_INC_SEARCH_BOARD );
 
+    // スレ一覧でdeleteを押したときに確認ダイアログを表示する
+    show_deldiag = cf.get_option( "show_deldiag", CONF_SHOW_DELDIAG );
+
     // ツリービューのスクロール量(行数)
     tree_scroll_size = cf.get_option( "tree_scroll_size", CONF_TREE_SCROLL_SIZE );
 
@@ -274,6 +275,9 @@ const bool ConfigItems::load()
     // 板一覧でカテゴリを常にひとつだけ開く
     open_one_category = cf.get_option( "open_one_category", CONF_OPEN_ONE_CATEGORY );
 
+    // お気に入りでカテゴリを常にひとつだけ開く
+    open_one_favorite = cf.get_option( "open_one_favorite", CONF_OPEN_ONE_FAVORITE );
+
     // 書き込み時に書き込み確認ダイアログを出さない
     always_write_ok = cf.get_option( "always_write_ok", CONF_ALWAYS_WRITE_OK );
 
@@ -283,6 +287,9 @@ const bool ConfigItems::load()
     // 書き込みログの最大サイズ
     maxsize_postlog = cf.get_option( "maxsize_postlog", CONF_MAXSIZE_POSTLOG );
 
+    // 書き込み履歴を保存
+    save_posthist = cf.get_option( "save_posthist", CONF_SAVE_POSTHIST );
+
     // 「書き込み中」のダイアログを表示しない
     hide_writing_dialog = cf.get_option( "hide_writing_dialog", CONF_HIDE_WRITING_DIALOG );
 
@@ -344,9 +351,6 @@ const bool ConfigItems::load()
     // ユーザーコマンドで選択できない項目を非表示にする
     hide_usrcmd = cf.get_option( "hide_usrcmd", CONF_HIDE_USRCMD );
 
-    // 指定した数よりもユーザーコマンドが多い場合はサブメニュー化する
-    max_show_usrcmd = cf.get_option( "max_show_usrcmd", CONF_MAX_SHOW_USRCMD );
-
     // スレビューで再読み込みボタンを押したときに全タブを更新する
     reload_allthreads = cf.get_option( "reload_allthreads", CONF_RELOAD_ALLTHREAD );
 
@@ -399,6 +403,9 @@ const bool ConfigItems::load()
     // 右ペーンが空の時にサイドバーを閉じるか
     expand_sidebar = cf.get_option( "expand_sidebar", CONF_EXPAND_SIDEBAR );
 
+    // 3ペーン時にスレ一覧やスレビューを最大化する
+    expand_rpane = cf.get_option( "expand_rpane", CONF_EXPAND_RPANE );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     migemodict_path = cf.get_option( "migemodict_path", CONF_MIGEMO_PATH );
@@ -432,11 +439,14 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "url_login2ch", url_login2ch );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
+    cf.update( "show_movediag", show_movediag );
     cf.update( "menu_search_title", menu_search_title );
     cf.update( "url_search_title", url_search_title );
     cf.update( "regex_search_title", regex_search_title );
     cf.update( "menu_search_web", menu_search_web );
     cf.update( "url_search_web", url_search_web );
+    cf.update( "url_writep2", url_writep2 );
+    cf.update( "url_resp2", url_resp2 );
 
     cf.update( "fontname_main", fontname[ FONT_MAIN ] );
     cf.update( "fontname_popup", fontname[ FONT_POPUP ] );
@@ -487,7 +497,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_image_popup", use_image_popup );
     cf.update( "use_image_view", use_image_view );
     cf.update( "use_inline_image", use_inline_image );
+    cf.update( "show_ssspicon", show_ssspicon );
     cf.update( "use_mosaic", use_mosaic );
+    cf.update( "mosaic_size", mosaic_size );
     cf.update( "zoom_to_fit", zoom_to_fit );
     cf.update( "del_img_day", del_img_day );
     cf.update( "del_imgabone_day", del_imgabone_day );
@@ -537,6 +549,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "show_oldarticle", show_oldarticle );
     cf.update( "newthread_hour", newthread_hour );
     cf.update( "inc_search_board", inc_search_board );
+    cf.update( "show_deldiag", show_deldiag );
 
     cf.update( "tree_scroll_size", tree_scroll_size );
     cf.update( "scroll_size", scroll_size );
@@ -550,9 +563,11 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "live_threshold", live_threshold );
 
     cf.update( "open_one_category", open_one_category );
+    cf.update( "open_one_favorite", open_one_favorite );
     cf.update( "always_write_ok", always_write_ok );
     cf.update( "save_postlog", save_postlog );
     cf.update( "maxsize_postlog", maxsize_postlog );
+    cf.update( "save_posthist", save_posthist );
     cf.update( "hide_writing_dialog", hide_writing_dialog );
     cf.update( "fold_message", fold_message );
     cf.update( "margin_popup", margin_popup );
@@ -579,7 +594,6 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "loose_url", loose_url );
 
     cf.update( "hide_usrcmd", hide_usrcmd );
-    cf.update( "max_show_usrcmd", max_show_usrcmd );
     cf.update( "reload_allthreads", reload_allthreads );
 
     cf.update( "tab_min_str", tab_min_str );
@@ -612,6 +626,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "abone_chain", abone_chain );
 
     cf.update( "expand_sidebar", expand_sidebar );
+    cf.update( "expand_rpane", expand_rpane );
 
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
@@ -621,6 +636,44 @@ void ConfigItems::save_impl( const std::string& path )
 }
 
 
+//
+// フォントのセット
+//
+void ConfigItems::set_fonts( JDLIB::ConfLoader& cf )
+{
+    const std::string defaultfont = get_default_font();
+
+    // フォント
+    fontname[ FONT_MAIN ] = cf.get_option( "fontname_main", defaultfont + " " + std::string( CONF_FONTSIZE_THREAD ) );
+
+    // ポップアップのフォント
+    fontname[ FONT_POPUP ] = cf.get_option( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
+
+    // スレ一覧のフォント
+    fontname[ FONT_BBS ] = cf.get_option( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
+
+    // 板一覧のフォント
+    fontname[ FONT_BOARD ] = cf.get_option( "fontname_board", fontname[ FONT_BBS ] );
+
+    // 書き込みウィンドウのフォント
+    fontname[ FONT_MESSAGE ] = cf.get_option( "fontname_message", fontname[ FONT_MAIN ] );
+
+    // Gtk::Entryのデフォルトフォント
+    fontname[ FONT_ENTRY_DEFAULT ] = MISC::get_entry_font();
+}
+
+
+//
+// フォントのリセット
+//
+void ConfigItems::reset_fonts()
+{
+    // dummyのConfLoaderをset_fonts()に渡してデフォルト値をセットする
+    JDLIB::ConfLoader cf( "", "dummy = dummy" );
+    set_fonts( cf );
+}
+
+
 //
 // 色のセット
 //
@@ -687,10 +740,10 @@ void ConfigItems::set_colors( JDLIB::ConfLoader& cf )
     str_color[ COLOR_BACK_SELECTION ] = cf.get_option( "cl_back_selection", CONF_COLOR_BACK_SELECTION );
 
     // ハイライトの背景色
-    str_color[ COLOR_BACK_HIGHLIGHT ] = cf.get_option( "cl_back_highlight", CONF_COLOR_HL );
+    str_color[ COLOR_BACK_HIGHLIGHT ] = cf.get_option( "cl_back_highlight", CONF_COLOR_BACK_HIGHLIGHT );
 
     // ハイライトの背景色(ツリー用)
-    str_color[ COLOR_BACK_HIGHLIGHT_TREE ] = cf.get_option( "cl_back_highlight_tree", CONF_COLOR_HL_TREE );
+    str_color[ COLOR_BACK_HIGHLIGHT_TREE ] = cf.get_option( "cl_back_highlight_tree", CONF_COLOR_BACK_HIGHLIGHT_TREE );
 
     // メッセージビューの背景色
     str_color[ COLOR_BACK_MESSAGE ] = cf.get_option( "cl_back_message", CONF_COLOR_BACK_MESSAGE );
@@ -714,7 +767,7 @@ void ConfigItems::set_colors( JDLIB::ConfLoader& cf )
     str_color[ COLOR_CHAR_BBS ] = cf.get_option( "cl_chr_bbs", CONF_COLOR_CHAR_BBS );
 
     // 板一覧のコメント
-    str_color[ COLOR_CHAR_BBS_COMMENT ] = cf.get_option( "cl_chr_bbs_com", CONF_COLOR_CHAR_BBS_COMENT );
+    str_color[ COLOR_CHAR_BBS_COMMENT ] = cf.get_option( "cl_chr_bbs_com", CONF_COLOR_CHAR_BBS_COMMENT );
 
     // スレ一覧の文字
     str_color[ COLOR_CHAR_BOARD ] = cf.get_option( "cl_chr_board", CONF_COLOR_CHAR_BOARD );
