@@ -22,6 +22,7 @@
 #include "global.h"
 #include "login2ch.h"
 #include "session.h"
+#include "updatemanager.h"
 
 #include <sstream>
 
@@ -29,6 +30,16 @@
 using namespace DBTREE;
 
 
+// 情報ファイルのパスをセット
+// デストラクタの中でCACHE::path_article_ext_info()などを呼ぶとabortするので
+// メンバ変数としてパスを取得しておく
+#define SET_INFOPATH() \
+do{ \
+m_path_article_info = CACHE::path_article_info( m_url, m_id ); \
+m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); \
+} while( false )
+
+
 // 情報ファイルから値を読み込み
 // JDLIB::ConfLoader では遅いので別に作成。オプションの順番に注意すること
 #define GET_INFOVALUE(target,targetname) \
@@ -51,6 +62,7 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_key( std::string() ),
       m_since_time( 0 ),
       m_since_date( std::string() ),
+      m_code( HTTP_INIT ),
       m_str_code( std::string() ),
       m_status( STATUS_UNKNOWN ),
       m_subject( std::string() ),
@@ -75,6 +87,7 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
 #endif
 
     memset( &m_access_time, 0, sizeof( struct timeval ) );
+    memset( &m_check_update_time, 0, sizeof( struct timeval ) );
     memset( &m_write_time, 0, sizeof( struct timeval ) );
 
     // m_url にURLセット
@@ -170,12 +183,12 @@ std::list< int > ArticleBase::get_res_name( const std::string& name )
 
 
 //
-// number番のレスの時刻
+// number番のレスの時刻を文字列で取得
 // 内部で regex　を使っているので遅い
 //
-const std::string ArticleBase::get_time( int number )
+const std::string ArticleBase::get_time_str( int number )
 {
-    return get_nodetree()->get_time( number );
+    return get_nodetree()->get_time_str( number );
 }
 
 
@@ -216,6 +229,8 @@ std::list< int > ArticleBase::get_res_id_name( const std::string& id_name )
 // list_jointは出力で true のスレは前のスレに連結される (例) "3+4" なら 4が3に連結
 std::list< int > ArticleBase::get_res_str_num( const std::string& str_num, std::list< bool >& list_joint )
 {
+    if( empty() ){ std::list< int > tmp; return tmp; }
+
     return get_nodetree()->get_res_str_num( str_num, list_joint );
 }
 
@@ -233,6 +248,19 @@ std::list< int > ArticleBase::get_res_bm()
 }
 
 
+// 書き込みしたレス番号をリストにして取得
+std::list< int > ArticleBase::get_res_posted()
+{
+    std::list< int > list_resnum;          
+    for( int i = 1; i <= m_number_load ; ++i ){
+        if( is_posted( i ) ) list_resnum.push_back( i );
+    }
+
+    // あぼーんしていてもリストから取り除かない
+    return list_resnum;
+}
+
+
 //
 // number番のレスを参照しているレス番号をリストにして取得
 //
@@ -247,6 +275,8 @@ std::list< int > ArticleBase::get_res_reference( int number )
 //
 std::list< int > ArticleBase::get_res_with_url()
 {
+    if( empty() ){ std::list< int > tmp; return tmp; }
+
     return get_nodetree()->get_res_with_url();
 }
 
@@ -258,6 +288,8 @@ std::list< int > ArticleBase::get_res_with_url()
 //
 std::list< int > ArticleBase::get_res_query( const std::string& query, bool mode_or )
 {
+    if( empty() ){ std::list< int > tmp; return tmp; }
+
     return get_nodetree()->get_res_query( query, mode_or );
 }
 
@@ -318,10 +350,7 @@ void ArticleBase::update_datbase( const std::string& datbase )
     m_url = datbase + m_id;
 
     // info ファイルのパスも更新
-    if( ! m_path_article_info.empty() ){
-        m_path_article_info = CACHE::path_article_info( m_url, m_id );  // info
-        m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); // 拡張info
-    }
+    if( ! m_path_article_info.empty() ) SET_INFOPATH();
 
 #ifdef _DEBUG
     if( !old_url.empty() ) std::cout << "ArticleBase::update_datbase from "  << old_url
@@ -378,14 +407,10 @@ void ArticleBase::set_subject( const std::string& subject )
 {
     if( subject.empty() ) return;
 
-    // 特殊文字の置き換え(応急処置)
+    // 特殊文字の置き換え
     if( subject.find( "&" ) != std::string::npos ){
 
-        std::string subject_tmp = subject;
-        subject_tmp = MISC::replace_str( subject_tmp, "&quot;", "\"" );
-        subject_tmp = MISC::replace_str( subject_tmp, "&lt;", "<" );
-        subject_tmp = MISC::replace_str( subject_tmp, "&gt;", ">" );
-        subject_tmp = MISC::replace_str( subject_tmp, "&amp;", "&" );
+        std::string subject_tmp = MISC::html_unescape( subject );
 
         if( subject_tmp != m_subject ){
             m_subject = subject_tmp;
@@ -423,6 +448,7 @@ void ArticleBase::set_number_seen( int number_seen )
     }
 }
 
+
 //
 // 書き込み時間更新
 //
@@ -430,7 +456,7 @@ void ArticleBase::update_writetime()
 {
     struct timeval tv;
     struct timezone tz;
-    if( gettimeofday( &tv, &tz ) == 0 ){
+    if( CONFIG::get_save_post_history() && gettimeofday( &tv, &tz ) == 0 ){
 
         m_write_time = tv;
         m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
@@ -444,22 +470,20 @@ void ArticleBase::update_writetime()
         CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
     }
 
-    // 板の書き込み時間も更新
+    // 板の書き込み時間を更新
     DBTREE::board_update_writetime( m_url );
 }
 
 
 //
-// 経過時間(秒)
+// 書き込み数
 //
-const time_t ArticleBase::get_write_pass()
+const int ArticleBase::get_num_posted()
 {
-    time_t ret = 0;
-    struct timeval tv;
-    struct timezone tz;
-
-    if( m_write_time.tv_sec && gettimeofday( &tv, &tz ) == 0 ) ret = MAX( 0, tv.tv_sec - m_write_time.tv_sec );
+    if( ! m_vec_posted.size() ) return 0;
 
+    int ret = 0;
+    for( int i = 1; i < MAX_RESNUMBER; ++i ) if( is_posted( i ) ) ++ret;
     return ret;
 }
 
@@ -710,7 +734,7 @@ void ArticleBase::set_abone_chain( bool set )
 //
 // ブックマークの数
 //
-int ArticleBase::get_num_bookmark()
+const int ArticleBase::get_num_bookmark()
 {
     if( ! m_vec_bookmark.size() ) return 0;
 
@@ -723,7 +747,7 @@ int ArticleBase::get_num_bookmark()
 //
 // ブックマークされているか
 //
-bool ArticleBase::is_bookmarked( int number )
+const bool ArticleBase::is_bookmarked( const int number )
 {
     if( number <= 0 || number > m_number_load ) return false;
 
@@ -739,7 +763,7 @@ bool ArticleBase::is_bookmarked( int number )
 //
 // ブックマークセット
 //
-void ArticleBase::set_bookmark( int number, bool set )
+void ArticleBase::set_bookmark( const int number, const bool set )
 {
     if( ! m_vec_bookmark.size() ) get_nodetree();
     if( number <= 0 || number > MAX_RESNUMBER ) return;
@@ -751,6 +775,58 @@ void ArticleBase::set_bookmark( int number, bool set )
 }
 
 
+//
+// 自分が書き込んだレスか
+//
+const bool ArticleBase::is_posted( const int number )
+{
+    if( number <= 0 || number > m_number_load ) return false;
+
+    // まだnodetreeが作られてなくて情報が得られてないのでnodetreeを作って情報取得
+    if( ! m_vec_posted.size() ) get_nodetree();
+
+    if( ! m_vec_posted.size() ) return false;
+
+    return ( m_vec_posted[ number ] );
+}
+
+
+// 自分の書き込みにレスしたか
+const bool ArticleBase::is_refer_posted( const int number )
+{
+    return get_nodetree()->is_refer_posted( number );
+}
+
+
+// 書き込み履歴のリセット
+void ArticleBase::clear_post_history()
+{
+    if( empty() ) return;
+    if( ! m_cached ) return;
+
+    read_info();
+    if( m_vec_posted.size() || m_write_time.tv_sec || m_write_time.tv_usec ){
+
+#ifdef _DEBUG
+        std::cout << "ArticleBase::clear_post_history size = " << m_vec_posted.size()
+                  << " time = " << m_write_time_date
+                  << " subject = " << m_subject << std::endl;
+#endif
+        m_vec_posted.clear();
+        memset( &m_write_time, 0, sizeof( struct timeval ) );
+        m_write_time_date = std::string();
+
+        // nodetreeが作られている時はnodetreeもリセット
+        if( m_nodetree ) m_nodetree->clear_post_history();
+
+        m_write_name = std::string();
+        m_write_mail = std::string();
+        m_write_fixname = false;
+        m_write_fixmail = false;
+
+        save_info( true );
+    }
+}
 
 
 //
@@ -767,7 +843,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
     if( ! m_nodetree ){
 
 #ifdef _DEBUG
-    std::cout << "ArticleBase::get_nodetree create " << m_url << std::endl;
+        std::cout << "ArticleBase::get_nodetree create " << m_url << std::endl;
 #endif
     
         m_nodetree = create_nodetree();
@@ -777,6 +853,9 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
         m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
                                      m_abone_transparent, m_abone_chain );
 
+        // 書き込み情報のコピー
+        m_nodetree->copy_post_info( m_vec_posted );
+
         m_nodetree->sig_updated().connect( sigc::mem_fun( *this, &ArticleBase::slot_node_updated ) );
         m_nodetree->sig_finished().connect( sigc::mem_fun( *this, &ArticleBase::slot_load_finished ) );
 
@@ -803,6 +882,7 @@ void ArticleBase::unlock_impl()
     std::cout << "ArticleBase::unlock_impl  url = " << m_url << std::endl;
 #endif
 
+    m_nodetree->terminate_load(); // deleteする前にスレッド停止
     m_nodetree.clear();
 
     // スレ情報保存
@@ -841,23 +921,54 @@ void ArticleBase::stop_load()
 // DAT落ちの場合はロードしないので、強制的にリロードしたいときは reset_status() で
 // ステータスをリセットしてからロードする
 //
-void ArticleBase::download_dat()
+// check_update == true の時はHEADによる更新チェックをおこなう
+//
+void ArticleBase::download_dat( const bool check_update )
 {
     if( empty() ) return;
 
 #ifdef _DEBUG
-    std::cout << "ArticleBase::download_dat " << m_url << std::endl;;
-    std::cout << "status = " << m_status << std::endl;
+    std::cout << "ArticleBase::download_dat " << m_url << " status = " << m_status << " checkupdate = " << check_update << std::endl;
 #endif
 
-    // DAT落ちしていてログイン中で無い時はロードしない
-    if( ! ( ( m_status & STATUS_OLD ) && ! LOGIN::get_login2ch()->login_now() ) ){
+    struct timeval tv;
+    struct timezone tz;
+    if( gettimeofday( &tv, &tz ) != 0 ) tv.tv_sec = 0;
+
+    if( check_update ){
+
+        if( ! SESSION::is_online() ) return;
+
+        // 一度更新チェックしたらしばらくは再チェックできないようにする
+        time_t passed = 0;
+        if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
 
 #ifdef _DEBUG
-        std::cout << "start\n";
-#endif       
-        get_nodetree()->download_dat();
+        std::cout << "check_update passed = " << passed << std::endl;
+#endif
+
+        if( passed <= CHECKUPDATE_MINSEC ) return;
     }
+
+    if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
+
+    // DAT落ちしていてログイン中で無い時はロードしない
+    if( ( m_status & STATUS_OLD ) && ! CORE::get_login2ch()->login_now() ){
+#ifdef _DEBUG
+        std::cout << "old !\n";
+#endif       
+        CORE::core_set_command( "toggle_favorite_icon", m_url );
+
+        // update_article_finish コマンドを送らないとキャッシュが無くて
+        // dat落ちしているスレのタブが空白になる
+        CORE::core_set_command( "update_article_finish", m_url );
+        return;
+    }
+
+#ifdef _DEBUG
+    std::cout << "start\n";
+#endif       
+    get_nodetree()->download_dat( check_update );
 }
 
 
@@ -870,6 +981,9 @@ void ArticleBase::slot_node_updated()
 {
     assert( m_nodetree );
 
+    // 更新チェック中
+    if( m_nodetree->is_checking_update() ) return;
+
 #ifdef _DEBUG
     std::cout << "ArticleBase::slot_node_updated" << std::endl;
 #endif
@@ -877,7 +991,6 @@ void ArticleBase::slot_node_updated()
     // nodetreeから情報取得
     if( ! m_nodetree->get_subject().empty() ) set_subject( m_nodetree->get_subject() );
 
-
     // スレが更新している場合
     if( m_number_load != m_nodetree->get_res_number() ){
 
@@ -904,14 +1017,9 @@ void ArticleBase::slot_load_finished()
 
     slot_node_updated();
 
-    // nodetreeから情報取得
+    // HTTPコード取得
+    int old_code = m_code;
     m_code = m_nodetree->get_code();
-    m_str_code = m_nodetree->get_str_code();
-    m_date_modified = m_nodetree->date_modified();
-    if( m_number_before_load < m_number_load ) m_number_new = m_number_load - m_number_before_load;
-    else m_number_new = 0;
-    m_number_before_load = m_number_load;
-    m_ext_err = m_nodetree->get_ext_err();
 
     // 状態更新
     int old_status = m_status;
@@ -921,6 +1029,7 @@ void ArticleBase::slot_load_finished()
         if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
+            CORE::core_set_command( "toggle_favorite_icon", m_url );
         }
 
         // 既にDAT落ち状態では無いときは通常状態にする
@@ -936,23 +1045,85 @@ void ArticleBase::slot_load_finished()
     // 状態が変わっていたら情報保存
     if( old_status != m_status ) m_save_info = true;
 
+    // 更新チェック
+    if( m_nodetree->is_checking_update() ){
+
+#ifdef _DEBUG
+        std::cout << "check_update code = " << m_code << std::endl;
+#endif
+
+        // スレタブとお気に入りのアイコンを更新
+        if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
+
+            show_updateicon( true );
+        }
+
+        // code と modified を戻しておく
+        m_code = old_code;
+        m_nodetree->set_date_modified( m_date_modified );
+
+#ifdef _DEBUG
+        std::cout << "check_update done\n";
+#endif
+
+        // 次のスレを更新チェック
+        CORE::get_checkupdate_manager()->pop_front();
+
+        return;
+    }
+
+    // nodetreeから情報取得
+    m_str_code = m_nodetree->get_str_code();
+    std::string m_old_modified = m_date_modified;
+    m_date_modified = m_nodetree->get_date_modified();
+    if( m_number_before_load < m_number_load ) m_number_new = m_number_load - m_number_before_load;
+    else m_number_new = 0;
+
+    // 書き込み情報
+    if( m_number_new && m_nodetree->get_vec_posted().size() ){
+
+        if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+
+        for( int i = m_number_before_load +1; i <= m_number_load; ++i ){
+
+            if( m_nodetree->get_vec_posted()[ i ] ) m_vec_posted[ i ] = true;
+            else m_vec_posted[ i ] = false;
+
+#ifdef _DEBUG
+            if( m_vec_posted[ i ] ) std::cout << "posted no = " << i << std::endl;
+#endif
+        }
+    }
+
+    m_number_before_load = m_number_load;
+    m_ext_err = m_nodetree->get_ext_err();
+
     // スレの数が0ならスレ情報はセーブしない
     if( ! m_number_load ) m_cached = false;
 
-    // スレが更新している場合はスレ情報を更新
-    else if( m_number_new ){
+    else{
 
-        struct timeval tv;
-        struct timezone tz;
-        if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
+        // スレが更新している場合はスレ情報を更新
+        if( m_number_new
+            || m_date_modified != m_old_modified // ときどき modified が誤って返るときがあるので最新の値を保存しておく
+            ){
 
-        if( m_number < m_number_load ) m_number = m_number_load;
-        m_number_seen = m_number_load;
+            struct timeval tv;
+            struct timezone tz;
+            if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
 
-        m_cached = true;
-        m_read_info = true;
-        m_save_info = true;
-        m_enable_load = false;
+            if( m_number < m_number_load ) m_number = m_number_load;
+
+            m_cached = true;
+            m_read_info = true;
+            m_save_info = true;
+            m_enable_load = false;
+
+            // 情報ファイルのパスをセット
+            if( m_path_article_info.empty() ) SET_INFOPATH();
+
+            show_updateicon( false );
+        }
     }
 
 #ifdef _DEBUG
@@ -979,11 +1150,44 @@ void ArticleBase::slot_load_finished()
 
 
 
+//
+// 更新アイコン表示
+//
+// update == true の時に表示。falseなら戻す
+//
+void ArticleBase::show_updateicon( const bool update )
+{
+#ifdef _DEBUG
+    std::cout << "ArticleBase::show_updateicon url = " << m_url << " update = " << update << " status = " << m_status << std::endl;
+#endif
+
+    struct timeval tv;
+    struct timezone tz;
+    if( gettimeofday( &tv, &tz ) != 0 ) m_check_update_time = tv;
+
+    if( update ){
+
+        if( ! ( m_status & STATUS_UPDATE ) ){
+            m_status |= STATUS_UPDATE;
+            CORE::core_set_command( "toggle_article_icon", m_url);
+            CORE::core_set_command( "toggle_favorite_icon", m_url );
+        }
+    }
+    else{
+
+        // お気に入りのアイコン表示を戻す。スレタブのアイコンの方はArticleViewが戻す
+        if( m_status & STATUS_UPDATE ){
+            m_status &= ~STATUS_UPDATE;
+            CORE::core_set_command( "toggle_favorite_icon", m_url );
+        }
+    }
+}
+
 
 //
 // キャッシュ削除
 //
-void ArticleBase::delete_cache()
+void ArticleBase::delete_cache( const bool cache_only )
 {
 #ifdef _DEBUG
     std::cout << "ArticleBase::delete_cache  url = " << m_url << std::endl;
@@ -991,51 +1195,64 @@ void ArticleBase::delete_cache()
 
     if( empty() ) return;
 
-    if( m_bookmarked_thread ){
-        SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」はブックマークされています。\n\nスレを削除しますか？"
+    if( ! cache_only && m_bookmarked_thread ){
+        SKELETON::MsgDiag mdiag( NULL, "「" + get_subject() + "」にはしおりが付けられています。\n\nスレを削除しますか？\n\nしおりを解除するにはスレの上で右クリックしてしおり解除を選択してください。"
                                   ,false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         mdiag.set_default_response( Gtk::RESPONSE_YES );
         if( mdiag.run() == Gtk::RESPONSE_NO ) return;
     }
 
     m_number_load = m_number_seen = m_number_before_load = 0;
+    m_cached = false;
     m_status = STATUS_UNKNOWN;
     m_date_modified.clear();
     memset( &m_access_time, 0, sizeof( struct timeval ) );
-    memset( &m_write_time, 0, sizeof( struct timeval ) );
-    m_write_time_date.clear();
+    memset( &m_check_update_time, 0, sizeof( struct timeval ) );
 
-    m_write_name.clear();
-    m_write_mail.clear();
-    m_write_fixname = false;
-    m_write_fixmail = false;
+    if( ! cache_only ){
 
-    m_vec_bookmark.clear();
-    m_list_abone_id.clear();
-    m_list_abone_name.clear();
-    m_list_abone_word.clear();
-    m_list_abone_regex.clear();
-    m_vec_abone_res.clear();
-    m_abone_transparent = false;
-    m_abone_chain = false;
-    m_cached = false;
-    m_read_info = false;
-    m_save_info = false;
-    m_enable_load = false;
-    m_bookmarked_thread = false;
+        memset( &m_write_time, 0, sizeof( struct timeval ) );
+        m_write_time_date.clear();
+
+        m_code =  HTTP_INIT;
+        m_str_code =  std::string();
+
+        m_write_name.clear();
+        m_write_mail.clear();
+        m_write_fixname = false;
+        m_write_fixmail = false;
+
+        m_vec_bookmark.clear();
+        m_vec_posted.clear();
+        m_list_abone_id.clear();
+        m_list_abone_name.clear();
+        m_list_abone_word.clear();
+        m_list_abone_regex.clear();
+        m_vec_abone_res.clear();
+        m_abone_transparent = false;
+        m_abone_chain = false;
+        m_read_info = false;
+        m_save_info = false;
+        m_enable_load = false;
+        m_bookmarked_thread = false;
     
+        // info
+        if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
+
+        // 拡張info
+        if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
+
+    }
+
     // キャッシュ
     std::string path_dat = CACHE::path_dat( m_url );
     if( CACHE::file_exists( path_dat ) == CACHE::EXIST_FILE ) unlink( path_dat.c_str() );
 
-    // info
-    if( CACHE::file_exists( m_path_article_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_info.c_str() );
-
-    // 拡張info
-    if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ) unlink( m_path_article_ext_info.c_str() );
-
     // BoardViewの行を更新
     CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
+
+    // お気に入りのアイコン表示を戻す
+    CORE::core_set_command( "toggle_favorite_icon", m_url );
 }
 
 
@@ -1055,7 +1272,7 @@ bool ArticleBase::save_dat( const std::string& path_to )
     std::string name = MISC::get_filename( path_to );
     if( name.empty() ) name = MISC::get_filename( m_url );    
 
-    std::string save_to = CACHE::open_save_diag( NULL, CACHE::path_dat( m_url ), dir + name );
+    std::string save_to = CACHE::copy_file( NULL, CACHE::path_dat( m_url ), dir + name, CACHE::FILE_TYPE_DAT );
 
     if( ! save_to.empty() ){
         SESSION::set_dir_dat_save( MISC::get_dir( save_to ) );
@@ -1075,24 +1292,21 @@ bool ArticleBase::save_dat( const std::string& path_to )
 //
 void ArticleBase::read_info()
 {
-    // 情報ファイルのパス
-    // デストラクタの中でCACHE::path_article_ext_info()などを呼ぶとabortするので
-    // パスを取得しておく
-    if(  m_path_article_info.empty() ){
-        m_path_article_info = CACHE::path_article_info( m_url, m_id );  // info
-        m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); // 拡張info
-    }
-
+    if( m_read_info ) return; // 一度読んだら2度読みしない
     if( empty() ) return;
     if( ! m_cached ) return;  // キャッシュがないなら読まない
-    if( m_read_info ) return; // 一度読んだら2度読みしない
-    m_read_info = true;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::read_info :  url = " << m_url << std::endl;
 #endif
 
-    if( CACHE::file_exists( m_path_article_ext_info ) == CACHE::EXIST_FILE ){
+    m_read_info = true;
+
+    // 情報ファイルのパスをセット
+    if( m_path_article_info.empty() ) SET_INFOPATH();
+
+    int ret = CACHE::file_exists( m_path_article_ext_info );
+    if( ret == CACHE::EXIST_FILE ){
 
         std::string str_info, str_tmp;
         std::list< std::string > list_tmp;
@@ -1145,7 +1359,7 @@ void ArticleBase::read_info()
                 m_write_time.tv_usec = atoi( ( *(it_tmp++) ).c_str() );
             }
 
-            m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
+            if( m_write_time.tv_sec ) m_write_time_date = MISC::timettostr( m_write_time.tv_sec );
         }
 
         // write name
@@ -1170,6 +1384,7 @@ void ArticleBase::read_info()
         m_status = STATUS_UNKNOWN;
         GET_INFOVALUE( str_tmp, "status = " );
         if( ! str_tmp.empty() ) m_status = atoi( str_tmp.c_str() );
+        m_status &= ~STATUS_UPDATE; // 更新可能状態解除
 
         // あぼーん ID
         GET_INFOVALUE( str_tmp, "aboneid = " );
@@ -1213,7 +1428,7 @@ void ArticleBase::read_info()
         if( ! str_tmp.empty() ) m_abone_chain = atoi( str_tmp.c_str() );
 
         // レス番号あぼーん
-        m_abone_chain = false;
+        m_vec_abone_res.clear();
         GET_INFOVALUE( str_tmp, "aboneres = " );
         if( ! str_tmp.empty() ){
 
@@ -1232,6 +1447,21 @@ void ArticleBase::read_info()
         m_bookmarked_thread = false;
         GET_INFOVALUE( str_tmp, "bkmark_thread = " );
         if( ! str_tmp.empty() ) m_bookmarked_thread = atoi( str_tmp.c_str() );
+
+        // 書き込みしたレス番号
+        GET_INFOVALUE( str_tmp, "posted = " );
+        if( ! str_tmp.empty() ){
+
+            if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+
+            list_tmp = MISC::split_line( str_tmp );
+            it_tmp = list_tmp.begin();
+            for( ; it_tmp != list_tmp.end(); ++it_tmp ){
+                int number = atoi( (*it_tmp).c_str() );
+                if( !(*it_tmp).empty() ) m_vec_posted[ number ] = true;
+                else m_vec_posted[ number ] = false;
+            }
+        }
     }
 
     // キャッシュはあるけど情報ファイルが無い場合
@@ -1241,6 +1471,8 @@ void ArticleBase::read_info()
 #ifdef _DEBUG
         std::cout << "ArticleBase::read_info : update info " << m_url << std::endl;
         std::cout << "load = " << m_number_load << " subject = " << m_subject << std::endl;
+        std::cout << "ret = " << ret << std::endl;
+        std::cout << "path = " << m_path_article_ext_info << std::endl;
 #endif
 
         CORE::core_set_command( "set_status","", "スレ情報更新中・・・しばらくお待ち下さい" );
@@ -1252,6 +1484,7 @@ void ArticleBase::read_info()
         if( !m_number_load ){
             m_number_load = 1;
             m_status |= STATUS_BROKEN;
+            MISC::MSG( "updating failed" );
         }
         
         m_number_before_load = m_number_load;
@@ -1303,8 +1536,13 @@ void ArticleBase::read_info()
         for( int i = 1; i <= m_number_load; ++i ) if( m_vec_bookmark[ i ] ) std::cout << " " << i;
         std::cout << std::endl;
     }
-#endif
 
+    if( m_vec_posted.size() ){
+        std::cout << "posted =";
+        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_posted[ i ] ) std::cout << " " << i;
+        std::cout << std::endl;
+    }
+#endif
 }
 
 
@@ -1325,6 +1563,12 @@ void ArticleBase::save_info( bool force )
 
     if( m_path_article_ext_info.empty() ) return;
 
+#ifdef _DEBUG
+    std::cout << "ArticleBase::save_info force = " << force << std::endl;
+    std::cout << "path_article_info = " << m_path_article_info << std::endl;
+    std::cout << "path_article_ext_info = " << m_path_article_ext_info << std::endl;
+#endif
+
     // 書き込み時間
     std::ostringstream ss_write;
     ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
@@ -1347,6 +1591,12 @@ void ArticleBase::save_info( bool force )
         for( int i = 1; i <= m_number_load; ++i ) if( m_vec_bookmark[ i ] ) ss_bookmark << " " << i;
     }
 
+    // 書き込み
+    std::ostringstream ss_posted;
+    if( m_vec_posted.size() ){
+        for( int i = 1; i <= m_number_load; ++i ) if( m_vec_posted[ i ] ) ss_posted << " " << i;
+    }
+
     std::ostringstream sstr;
     sstr << "subject = " << m_subject << std::endl
          << "org_host = " << m_org_host << std::endl
@@ -1369,6 +1619,7 @@ void ArticleBase::save_info( bool force )
          << "abonechain = " << m_abone_chain << std::endl
          << "aboneres = " << ss_abone_res.str() << std::endl
          << "bkmark_thread = " << m_bookmarked_thread << std::endl
+         << "posted = " << ss_posted.str() << std::endl
     ;
 
 #ifdef _DEBUG
@@ -1413,14 +1664,30 @@ void ArticleBase::save_navi2ch_info()
 
         std::list< std::string > lists = MISC::get_elisp_lists( str_info );
         std::list< std::string >::iterator it = lists.begin();
-        ++it;
-        name = *( it++ );
-        ++it;
-        hide = *( it++ );
-        important = *( it++ );
-        unfilter = *( it++ );
-        mail = *( it++ );
-        kako = *( it++ );        
+
+        do{
+            ++it;
+            if( it == lists.end() ) break;
+            name = *( it++ );
+
+            if( it == lists.end() ) break;
+            ++it;
+            if( it == lists.end() ) break;
+            hide = *( it++ );
+
+            if( it == lists.end() ) break;
+            important = *( it++ );
+
+            if( it == lists.end() ) break;
+            unfilter = *( it++ );
+
+            if( it == lists.end() ) break;
+            mail = *( it++ );
+
+            if( it == lists.end() ) break;
+            kako = *( it++ );
+
+        } while(0);
     }
 
     std::ostringstream sstr;
