@@ -12,6 +12,7 @@
 
 #include <sstream>
 #include <cstring>
+#include <cstdio>
 #include <cstdlib>
 
 
@@ -781,7 +782,7 @@ int MISC::is_url_scheme( const char* str_in, int* length )
     int len = 0;
 
     // 候補になり得ない場合は以降の処理はしない
-    if( *str_in != 'h' && *str_in != 'f' && *str_in != 't' ) return scheme;
+    if( *str_in != 'h' && *str_in != 'f' && *str_in != 't' && *str_in != 's' ) return scheme;
 
     // http https
     if( *str_in == 'h' && *( str_in + 1 ) == 't'
@@ -811,6 +812,16 @@ int MISC::is_url_scheme( const char* str_in, int* length )
         len = 2;
         if( *( str_in + len ) == 's' ) ++len;
     }
+    // sssp
+    // デフォルトでモザイクを解除するのでimg.2ch以外のアドレスにはリンクを張らない
+    else if( *str_in == 's' && *( str_in + 1 ) == 's' && *( str_in + 2 ) == 's' && *( str_in + 3 ) == 'p'
+             && *( str_in + 7 ) == 'i' && *( str_in + 8 ) == 'm' && *( str_in + 9 ) == 'g' && *( str_in + 10 ) == '.'
+             && *( str_in + 11 ) == '2' && *( str_in + 12 ) == 'c' && *( str_in + 13 ) == 'h'
+        )
+    {
+        scheme = SCHEME_SSSP;
+        len = 4;
+    }
 
     // 各スキーム後に続く共通の"://"
     if( *( str_in + len ) == ':' && *( str_in + len + 1 ) == '/'
