@@ -39,10 +39,13 @@ namespace MESSAGE
                    const std::string& subject,  const std::string& msg, const std::string& name, const std::string& mail );
 
         //　書き込みログ取得
-        const std::string get_postlog( const int num );
+        const std::string get_post_log( const int num );
 
-        // postlog-* の最大数
+        // ログファイル( log/postlog-* ) の最大数
         const int get_max_num_of_log();
+
+        // ログ削除
+        void clear_post_log();
     };
 
     ///////////////////////////////////////
