@@ -17,11 +17,22 @@ namespace CORE
     enum
     {
         PREFDIAG_PASSWD,
+        PREFDIAG_PRIVARY,
         PREFDIAG_BROWSER,
+        PREFDIAG_LINKFILTER,
+        PREFDIAG_USRCMD,
         PREFDIAG_PROXY,
         PREFDIAG_GLOBALABONETHREAD,
         PREFDIAG_GLOBALABONE,
         PREFDIAG_FONTCOLOR,
+        PREFDIAG_LIVE,
+
+        PREFDIAG_MAINITEM,
+        PREFDIAG_SIDEBARITEM,
+        PREFDIAG_BOARDITEM,
+        PREFDIAG_BOARDITEMCOLUM,
+        PREFDIAG_ARTICLEITEM,
+        PREFDIAG_MSGITEM,
 
         PREFDIAG_DELIMG,
 
@@ -29,6 +40,12 @@ namespace CORE
         PREFDIAG_ARTICLE,
         PREFDIAG_IMAGE,
 
+        PREFDIAG_KEY,
+        PREFDIAG_MOUSE,
+        PREFDIAG_BUTTON,
+
+        PREFDIAG_ABOUTCONFIG,
+
         PREFDIAG_NONE
     };
     
