@@ -3,17 +3,23 @@
 //#define _DEBUG
 #include "jddebug.h"
 
+#include "admin.h"
 #include "view.h"
 
 #include "jdlib/miscutil.h"
 
+#include "history/historymanager.h"
+
 #include "global.h"
 #include "session.h"
 #include "command.h"
 
 using namespace SKELETON;
 
-#define KEYJUMP_TIMEOUT 1000
+enum
+{
+    KEYJUMP_TIMEOUT = 1000
+};
 
 
 View::View( const std::string& url, const std::string& arg1 ,const std::string& arg2 )
@@ -24,27 +30,49 @@ View::View( const std::string& url, const std::string& arg1 ,const std::string&
       m_autoreload_mode( AUTORELOAD_NOT ),
       m_keyjump_counter( 0 ),
       m_keyjump_num( 0 ),
-      m_locked( false )
+      m_lockable( true ),
+      m_locked( false ),
+      m_id_toolbar( 0 )
 {}
 
 
 //
-// host の更新
+// URL 変更
 //
-// 移転があったときなどにadminから呼ばれる
+// update_history == true の時は 履歴も更新
 //
-void View::update_host( const std::string& host )
+void View::set_url( const std::string& url_new, const bool update_history )
 {
-#ifdef _DEBUG
-    std::string old_url = m_url;
-#endif
+    if( update_history && ! m_url.empty() && ! url_new.empty() && m_url != url_new ){
 
-    m_url = host + m_url.substr( MISC::get_hostname( m_url ).length() );
+        // View履歴のURLを更新
+        HISTORY::get_history_manager()->replace_url_viewhistory( m_url, url_new );
+
+        // ツールバーのURLを更新
+        get_admin()->set_command( "update_toolbar_url", m_url, url_new );
+    }
+
+    m_url = url_new;
+}
+
+
+//
+// url 更新
+//
+// 移転があったときなどにadminから呼び出される
+//
+void View::update_url( const std::string& url_old, const std::string& url_new )
+{
+    if( m_url.find( url_old ) != 0 ) return;
+
+    std::string url = url_new + m_url.substr( url_old.length() );
 
 #ifdef _DEBUG
-    if( ! old_url.empty() ) std::cout << "View::update_host from "  << old_url
-                                     << " to " << m_url << std::endl;
+    std::cout << "View::update_url\n";
+    std::cout << m_url << " -> " << url << std::endl;
 #endif
+
+    set_url( url, true );
 }
 
 
@@ -52,8 +80,8 @@ void View::update_host( const std::string& host )
 // clock_in_always()はviewの種類に依らず常に呼び出されるので重い処理を含めてはいけない
 void View::clock_in_always()
 {
-    // オートリロード
-    if( inc_autoreload_counter() ) reload();
+    // タブ単位でのオートリロードモード
+    if( m_autoreload_mode == AUTORELOAD_ONCE && inc_autoreload_counter() ) reload();
 
     // キーボード数字入力ジャンプ
     if( inc_keyjump_counter() ){
@@ -84,6 +112,7 @@ bool View::inc_autoreload_counter()
 void View::set_autoreload_mode( int mode, int sec )
 {
     if( ! m_enable_autoreload ) return;
+    if( m_autoreload_mode != AUTORELOAD_NOT && mode != AUTORELOAD_NOT ) return;
 
     m_autoreload_mode = mode;
     m_autoreload_sec = sec;
@@ -95,6 +124,8 @@ void View::set_autoreload_mode( int mode, int sec )
 void View::reset_autoreload_counter()
 {
     m_autoreload_counter = 0;
+
+    // オートリロードのモードがAUTORELOAD_ONCEの時はオートリロード停止
     if( m_autoreload_mode == AUTORELOAD_ONCE ) m_autoreload_mode = AUTORELOAD_NOT;
 }
 
@@ -123,7 +154,7 @@ void View::reset_keyjump_counter()
 
 
 // 数字入力ジャンプ用に sig_key_press() から呼び出す
-void View::release_keyjump_key( int key )
+const bool View::release_keyjump_key( int key )
 {
     // キーパッド対応
     if( key >= GDK_KP_0 && key <= GDK_KP_9 ) key = key - GDK_KP_0 + GDK_0;
@@ -134,7 +165,10 @@ void View::release_keyjump_key( int key )
         m_keyjump_num += key - '0';
 
         CORE::core_set_command( "set_info", "", MISC::itostr( m_keyjump_num ) );
+        return true;
     }
+
+    return false;
 }
 
 
