@@ -12,6 +12,7 @@
 #include "dndmanager.h"
 #include "command.h"
 
+#include <gtk/gtkwindow.h>
 
 enum
 {
@@ -47,6 +48,9 @@ using namespace SKELETON;
 // メッセージウィンドウでは m_mginfo が不要なので need_mginfo = false になる
 JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     : Gtk::Window( Gtk::WINDOW_TOPLEVEL ),
+      m_gtkwidget( NULL ),
+      m_gtkwindow( NULL ),
+      m_grand_parent_class( NULL ),
       m_win_moved( false ),
       m_fold_when_focusout( fold_when_focusout ),
       m_boot( true ),
@@ -80,6 +84,11 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     m_statbar.show_all_children();
 
     add( m_vbox );
+
+    m_gtkwidget = GTK_WIDGET( gobj() );
+    m_gtkwindow = GTK_WINDOW( gobj() );
+    gpointer parent_class = g_type_class_peek_parent( G_OBJECT_GET_CLASS( gobj() ) );
+    m_grand_parent_class = g_type_class_peek_parent( parent_class );
 }
 
 
@@ -690,3 +699,24 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
 
     return Gtk::Window::on_configure_event( event );
 }
+
+
+// uimなど、漢字変換モードの途中でctrl+qを押すとキーアクセレータが
+// 優先されてJDが終了する問題があった。
+//
+// gedit-window.c の gedit_window_key_press_event を見ると
+// gtk_window_propagate_key_event() を実行した後でキーアクセレータ
+// の処理をするようにしていたのでJDもそうした。
+bool JDWindow::on_key_press_event( GdkEventKey* event )
+{
+    if( gtk_window_propagate_key_event( m_gtkwindow, event ) ) return true;
+
+    if( gtk_window_activate_key( m_gtkwindow, event ) ) return true;
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::on_key_press_event key = " << event->keyval << std::endl;
+    std::cout << m_grand_parent_class << " - " << m_gtkwidget << std::endl;
+#endif
+
+    return GTK_WIDGET_CLASS( m_grand_parent_class )->key_press_event( m_gtkwidget, event );
+}
