@@ -9,8 +9,11 @@
 #include "board/boardview.h"
 
 #include "article/articleview.h"
+#include "article/articleviewsearch.h"
 #include "article/articleviewpreview.h"
+#include "article/articleviewinfo.h"
 #include "article/articleviewpopup.h"
+#include "article/articleviewetc.h"
 
 #include "image/imageview.h"
 #include "image/imageviewicon.h"
@@ -53,6 +56,9 @@ SKELETON::View* CORE::ViewFactory( int type, const std::string& url, VIEWFACTORY
         case VIEW_ARTICLEBM:
             return new ARTICLE::ArticleViewBM( url );
 
+        case VIEW_ARTICLEPOST:
+            return new ARTICLE::ArticleViewPost( url );
+
         case VIEW_ARTICLEURL:
             return new ARTICLE::ArticleViewURL( url );
 
@@ -65,8 +71,20 @@ SKELETON::View* CORE::ViewFactory( int type, const std::string& url, VIEWFACTORY
         case VIEW_ARTICLEPREVIEW:
             return new ARTICLE::ArticleViewPreview( url );
 
-        case VIEW_ARTICLESEARCHCAHCE:
-            return new ARTICLE::ArticleViewSearchCache( url, args.arg1, ( args.arg2 == "OR" ), ( args.arg3 == "all" ) );
+        case VIEW_ARTICLEINFO:
+            return new ARTICLE::ArticleViewInfo( url );
+
+        case VIEW_ARTICLESEARCHLOG:
+            return new ARTICLE::ArticleViewSearch( url, args.arg1, ARTICLE::SEARCHMODE_LOG , ( args.arg2 == "exec" ), ( args.arg3 == "OR" ) );
+
+        case VIEW_ARTICLESEARCHALLLOG:
+            return new ARTICLE::ArticleViewSearch( url, args.arg1, ARTICLE::SEARCHMODE_ALLLOG, ( args.arg2 == "exec" ), (args.arg3 == "OR" ) );
+
+        case VIEW_ARTICLESEARCHTITLE:
+            return new ARTICLE::ArticleViewSearch( url, args.arg1, ARTICLE::SEARCHMODE_TITLE, ( args.arg2 == "exec" ), (args.arg3 == "OR" ) );
+
+        case VIEW_ARTICLEPOSTLOG:
+            return new ARTICLE::ArticleViewPostlog( url, atoi( args.arg1.c_str() ) );
 
             /////////////////
 
